
__copyright__    = 'Copyright (C) 2023-2024 unchainworks'
__version__      = '1.0.5'
__license__      = 'BSD-3-Clause'
__author__       = 'unchainworks'
__author_email__ = 'kajin0318@gmail.com'
__url__          = 'https://github.com/kaioman/Stabdifspy.git'